@@ -1,11 +1,11 @@
+//go:build !windows
+
 package main
 
 import (
 	"errors"
 	"fmt"
 	"strings"
-	"unicode"
-	"unicode/utf8"
 )
 
 func splitCFlagsFromArgs(in []string) (args, cflags []string) {
@@ -76,8 +76,3 @@ func splitArguments(in string) ([]string, error) {
 
 	return result, nil
 }
-
-func toUpperFirst(str string) string {
-	first, n := utf8.DecodeRuneInString(str)
-	return string(unicode.ToUpper(first)) + str[n:]
-}
